# 🌀 blueness

🌀 the blueness of ai enables [blue plugins](https://github.com/kamangir/blue-plugin).

```bash
pip install blueness
```

---

[![PyPI version](https://img.shields.io/pypi/v/blueness.svg)](https://pypi.org/project/blueness/)
